@@ -21,7 +21,7 @@ try:  # pragma: no cover
 except NameError:  # pragma: no cover
     str_type = str
 
-__version__ = '1.3.3'
+__version__ = '1.4.0'
 
 __all__ = ('make', 'make_qr', 'make_micro', 'make_sequence', 'QRCode',
            'QRCodeSequence', 'DataOverflowError')
@@ -517,21 +517,26 @@ class QRCode:
         """
         return writers.as_png_data_uri(self.matrix, self._version, **kw)
 
-    def terminal(self, out=None, border=None):
+    def terminal(self, out=None, border=None, compact=False):
         """\
-        Serializes the matrix as ANSI escape code.
+        Serializes the matrix as ANSI escape code or Unicode Block Elements
+        (if ``compact`` is ``True``).
 
         Under Windows, no ANSI escape sequence is generated but the Windows
         API is used *unless* :paramref:`out <segno.QRCode.terminal.out>`
-        is a writable object or using WinAPI fails.
+        is a writable object or using WinAPI fails or if ``compact`` is ``True``.
 
         :param out: Filename or a file-like object supporting to write text.
                 If ``None`` (default), the matrix is written to :py:class:`sys.stdout`.
         :param int border: Integer indicating the size of the quiet zone.
                 If set to ``None`` (default), the recommended border size
                 will be used (``4`` for QR Codes, ``2`` for Micro QR Codes).
+        :param bool compact: Indicates if a more compact QR code should be shown
+                (default: ``False``).
         """
-        if out is None and sys.platform == 'win32':  # pragma: no cover
+        if compact:
+            writers.write_terminal_compact(self.matrix, self._version, out or sys.stdout, border)
+        elif out is None and sys.platform == 'win32':  # pragma: no cover
             # Windows < 10 does not support ANSI escape sequences, try to
             # call the a Windows specific terminal output which uses the
             # Windows API.
@@ -539,11 +544,9 @@ class QRCode:
                 writers.write_terminal_win(self.matrix, self._version, border)
             except OSError:
                 # Use the standard output even if it may print garbage
-                writers.write_terminal(self.matrix, self._version, sys.stdout,
-                                       border)
+                writers.write_terminal(self.matrix, self._version, sys.stdout, border)
         else:
-            writers.write_terminal(self.matrix, self._version, out or sys.stdout,
-                                   border)
+            writers.write_terminal(self.matrix, self._version, out or sys.stdout, border)
 
     def save(self, out, kind=None, **kw):
         """\
@@ -973,14 +976,14 @@ class QRCodeSequence(tuple):
     def __new__(cls, qrcodes):
         return super(QRCodeSequence, cls).__new__(cls, qrcodes)
 
-    def terminal(self, out=None, border=None):
+    def terminal(self, out=None, border=None, compact=False):
         """\
         Serializes the sequence of QR codes as ANSI escape code.
 
         See :py:meth:`QRCode.terminal()` for details.
         """
         for qrcode in self:
-            qrcode.terminal(out=out, border=border)
+            qrcode.terminal(out=out, border=border, compact=compact)
 
     def save(self, out, kind=None, **kw):
         """\
